/*
-------------------------------------------------------------------------------
    This file is a part of the VST Preset Generator
    Copyright (C) 2007  Francois Mazen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-------------------------------------------------------------------------------
  Name: vstlistmodel.cpp
  Author: Francois Mazen
  Date: 28/05/07 16:25
  Description: class using Qt's XML functions in order to read and save the
               list of VST plugins (.vpg) with their header's parameters
-------------------------------------------------------------------------------
*/

#include "vstlistmodel.h"
#include "vpgversion.h"

#include <QtWidgets>

//-----------------------------------------------------------------------------
VSTListModel::VSTListModel(QWidget * parent) : QAbstractListModel(parent)
{
    this->parentWidget = parent;
    this->areDataWritten = false;
}

//-----------------------------------------------------------------------------
VSTListModel::~VSTListModel()
{
    clearListWithoutRefresh();
}

//-----------------------------------------------------------------------------
QVariant VSTListModel::data(const QModelIndex & index, int role ) const
{
    QVariant returnedData;

    //must return only the name of the header
    if(index.isValid() && index.row() >= 0 && index.row() < this->fxHeaderList.size())
    {
        if(role == Qt::DisplayRole)
        {
            returnedData = this->fxHeaderList.value(index.row())->name;
        }
    }

    return returnedData;
}

//-----------------------------------------------------------------------------
QVariant VSTListModel::headerData(int /*section*/, Qt::Orientation /*orientation*/, int /*role*/ ) const
{
    return QVariant(); //nothing :)
}

//-----------------------------------------------------------------------------
int VSTListModel::rowCount(const QModelIndex& /*parent*/) const
{
    return this->fxHeaderList.size();
}

//-----------------------------------------------------------------------------
void VSTListModel::addPluginHeader(FxHeaderStruct* fxHeader)
{
    this->beginResetModel();

    addPluginHeaderWithoutRefresh(fxHeader);

    this->endResetModel();
}

//-----------------------------------------------------------------------------
void VSTListModel::addPluginHeaderWithoutRefresh(FxHeaderStruct* fxHeader)
{
    this->fxHeaderList.append(fxHeader);
    this->areDataWritten = false;
}

//-----------------------------------------------------------------------------
void VSTListModel::clearList()
{
    this->beginResetModel();

    clearListWithoutRefresh();

    this->endResetModel();
}

//-----------------------------------------------------------------------------
void VSTListModel::clearListWithoutRefresh()
{
    //delete the FxHeaderStruct stored in dataList
    for (int i = 0; i < this->fxHeaderList.size(); ++i)
    {
        delete this->fxHeaderList.at(i);
    }
    this->fxHeaderList.clear();
    this->areDataWritten = false;
}

//-----------------------------------------------------------------------------
bool VSTListModel::areDataSaved() const
{
    return this->areDataWritten;
}

//-----------------------------------------------------------------------------
void VSTListModel::setNeedSaving(bool doesNeedSaving)
{
    this->areDataWritten = !doesNeedSaving;
}

//-----------------------------------------------------------------------------
bool VSTListModel::isListEmpty() const
{
    return this->fxHeaderList.isEmpty();
}

//-----------------------------------------------------------------------------
FxHeaderStruct* VSTListModel::getPluginHeaderAtIndex(int index) const
{
    FxHeaderStruct* fxHeader = NULL;
    if(index >= 0 && index < this->fxHeaderList.size())
    {
        fxHeader = this->fxHeaderList.value(index);
    }
    return fxHeader;
}

//-----------------------------------------------------------------------------
const QList<FxHeaderStruct*>& VSTListModel::getPluginHeaders() const
{
    return this->fxHeaderList;
}

//-----------------------------------------------------------------------------
void VSTListModel::beginModelChangeWithoutRefresh()
{
    this->beginResetModel();
}

//-----------------------------------------------------------------------------
void VSTListModel::endModelChangeWithoutRefresh()
{
    this->endResetModel();
}

